@@ -1,4 +1,5 @@
 import typing
+import logging
 
 from textacy import extract
 
@@ -22,16 +23,19 @@ class SVOExtractor(Extractor):
             )
             for subject, verb, object in extract.subject_verb_object_triples(doc)
         ]
-        triples.extend(
-            [
-                self.create_triple(
-                    " ".join([str(x) for x in speaker]),
-                    " ".join([str(x) for x in cue]),
-                    " ".join([str(x) for x in content]),
-                    doc,
-                    is_quote=True,
-                )
-                for speaker, cue, content in extract.direct_quotations(doc)
-            ]
-        )
+        try:
+            triples.extend(
+                [
+                    self.create_triple(
+                        " ".join([str(x) for x in speaker]),
+                        " ".join([str(x) for x in cue]),
+                        " ".join([str(x) for x in content]),
+                        doc,
+                        is_quote=True,
+                    )
+                    for speaker, cue, content in extract.direct_quotations(doc)
+                ]
+            )
+        except ValueError:
+            logging.warn(f"Failed to extract quotations")
         return triples
